Command

Derive Macro Command 

#[derive(Command)]
{
    // Attributes available to this derive:
    #[command]
    #[option]
    #[argument]
}
#[derive(Command)] — generate a Command trait impl from attributed fields. Requires the default derive feature. Derive runi_cli::Command for a struct or enum.

On a struct, each field becomes an option or positional argument depending on its attribute and type. On an enum, each variant becomes a subcommand (the variant struct is registered on a Launcher<G>).