Skip to main contentModule launcher
Source - CLArgument
- A positional argument (required or optional).
- CLOption
- A single named option (
-v,--verbose, --count, etc.). - CommandSchema
- Schema for a command (root or subcommand). Build with the fluent API
or construct the struct literally for tests.
- HelpPrinter
- Format help output for a schema. The result is ANSI-styled when the
destination stream is a TTY and plain otherwise.
- Launcher
- Launcher before any subcommand has been registered.
- LauncherWithSubs
- Launcher that already has at least one subcommand registered.
- OptionParser
- Hand-rolled tokenizer. Translates a flat argv slice into a
ParseResult
guided by the schema. - ParseResult
- Outcome of parsing a raw argv slice against a
CommandSchema.
- Error
- Errors produced by the launcher when parsing command-line arguments.
- Command
- A command (root or subcommand) that knows how to produce its argument
schema and how to construct itself from a
ParseResult. - FromArg
- Convert a raw command-line argument string into a typed value.
- Runnable
- A root command that can be run standalone. The launcher calls
run after
parsing arguments when no subcommands are registered. - SubCommandOf
- A subcommand invoked in the context of a parent (global-options) struct
G.
- Result